
# Slot: has attribute type


connects an attribute to a class that describes it

URI: [biolink:clinical_measurement_has_attribute_type](https://w3id.org/biolink/vocab/clinical_measurement_has_attribute_type)


## Domain and Range

[ClinicalMeasurement](ClinicalMeasurement.md) &#8594;  <sub>1..1</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [has attribute type](has_attribute_type.md)

## Children


## Used by

 * [ClinicalMeasurement](ClinicalMeasurement.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | samples |
| **Narrow Mappings:** | | LOINC:has_modality_type |
|  | | LOINC:has_view_type |

